@@ -41,7 +41,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.8.1'; # VERSION
+our $VERSION = 'v0.8.2'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -505,7 +505,7 @@ sub configure {
             'max_target_perl' => $self->minimum_perl,
         } ],
 
-        [ 'Test::Fix' . 'me' ],
+        [ 'Test::Fixme' ],
 
         [ 'Test::Perl::Critic' => {
             'critic_config' => 'xt/perlcritic.ini',
@@ -845,7 +845,7 @@ sub configure {
             'hook' => [ q{
                 use autodie ':all';
                 system(
-                    'hg', 'commit', '-m', 'Post-release commit',
+                    'hg', 'commit', '-m', 'post-release',
                         qw{ .hgtags Changes VERSION }
                 );
             } ],
@@ -926,7 +926,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.8.1, released on 2015-09-25 20:00 UTC.
+Version v0.8.2, released on 2015-09-26 11:17 UTC.
 
 =head1 WHAT?
 
